<?php
$lang['info_detail_returnid'] = 'T&auml;t&auml; asetusta k&auml;ytet&auml;&auml;n m&auml;&auml;rittelem&auml;&auml;n sivu (ja sivupohja), jota k&auml;ytet&auml;&auml;n lis&auml;tietojen n&auml;ytt&auml;miseksi. Yksil&ouml;lliset uutisten URL-osoitteet eiv&auml;t toimi, jos t&auml;t&auml; asetusta ei ole asetettu toimivaksi sivuksi. Lis&auml;ksi, jos t&auml;m&auml; asetus on m&auml;&auml;ritelty, eik&auml; detailpage-parametria ole annettu uutistagissa, t&auml;t&auml; asetusta k&auml;ytet&auml;&auml;n lis&auml;tietolinkiss&auml;.';
$lang['title_detail_returnid'] = 'Oletus sivu detail n&auml;kym&auml;lle';
$lang['title_submission_settings'] = 'Uutisten L&auml;hetys Asetukset';
$lang['title_fesubmit_settings'] = 'Frontend L&auml;hetys Asetukset';
$lang['title_notification_settings'] = 'Huomautus Asetukset';
$lang['title_detail_settings'] = 'Detail N&auml;kym&auml;n Asetukset';
$lang['error_invalidurl'] = 'Virheellinen URL <em>(Mahdollisesti k&auml;yt&ouml;ss&auml;, tai sis&auml;lt&auml;&auml; virheellisi&auml; merkkej&auml;)</em>';
$lang['url'] = 'URL-osoite';
$lang['expired_searchable'] = 'Vanhentuneet artikkelit voivat esiinty&auml; hakutuloksissa';
$lang['helpshowall'] = 'N&auml;yt&auml; kaikki artikkelit, riippumatta p&auml;&auml;ttymisp&auml;iv&auml;m&auml;&auml;r&auml;st&auml;';
$lang['error_invaliddates'] = 'Yksi tai useampi annettu p&auml;iv&auml;m&auml;&auml;r&auml; oli virheellinen';
$lang['notify_n_draft_items_sub'] = '%d uutisartikkeli(a)';
$lang['notify_n_draft_items'] = 'Sinulla on %s, jotka eiv&auml;t ole julkaistu';
$lang['unlimited'] = 'Rajoittamaton';
$lang['none'] = 'Ei mit&auml;&auml;n';
$lang['anonymous'] = 'Anonyymi';
$lang['unknown'] = 'Tuntematon';
$lang['fesubmit_redirect'] = 'Sivun ID tai alias, jolle k&auml;ytt&auml;j&auml; ohjataan kun uusi uutisartikkeli l&auml;hetet&auml;&auml;n fesubmit-toiminnon kautta';
$lang['allow_summary_wysiwyg'] = 'Salli WYSIWYG-editorin k&auml;ytt&ouml; yhteenvetokent&auml;ss&auml;';
$lang['title_browsecat_template'] = 'Kategorian selauspohjan editori';
$lang['title_browsecat_sysdefault'] = 'Oletus kategorian selauspohja';
$lang['browsecattemplate'] = 'Kategorian selauspohjat';
$lang['error_filesize'] = 'Ladatun tiedoston koko ylitt&auml;&auml; sallitun koon';
$lang['post_date_desc'] = 'Julkaisupvm, laskeva';
$lang['post_date_asc'] = 'Julkaisupvm, nouseva';
$lang['expiry_date_desc'] = 'Vanhentumispvm, laskeva';
$lang['expiry_date_asc'] = 'Vanhentumispvm, nouseva';
$lang['title_desc'] = 'Otsikko laskeva';
$lang['title_asc'] = 'Otsikko nouseva';
$lang['status_desc'] = 'Tila laskeva';
$lang['status_asc'] = 'Tila nouseva';
$lang['fesubmit_status'] = 'Sivustolta kirjoitettujen uutisten oletustila';
$lang['error_invalidfiletype'] = 'Tiedostotyyppi ei ole sallittu';
$lang['error_upload'] = 'Tiedoston latauksessa tapahtui virhe';
$lang['error_movefile'] = 'Ei voitu luoda tiedostoa: %s';
$lang['error_mkdir'] = 'Ei voitu luoda kansiota: %s';
$lang['expiry_interval'] = 'Jos vanhentuminen on valittu, kuinka monta p&auml;iv&auml;&auml; uutinen on oletuksena voimassa';
$lang['removed'] = 'Poistettu';
$lang['msg_contenttype_removed'] = 'Uutiset sivutyyppi on poistettu. Ole hyv&auml; ja lis&auml;&auml; {news} tagi sopivilla parametreill&auml; sivupohjaan tai sivun sis&auml;lt&ouml;&ouml;n saadaksesi saman toiminnallisuuden';
$lang['delete_selected'] = 'Poista valitut artikkelit';
$lang['areyousure_deletemultiple'] = 'Haluatko varmasti poistaa artikkelit? \n Toimintoa ei voi peruuttaa!';
$lang['error_templatenamexists'] = 'T&auml;m&auml;nniminen pohja on jo olemassa';
$lang['error_noarticlesselected'] = 'Ei valittuja artikkeleita';
$lang['reassign_category'] = 'Vaihda kategoria';
$lang['select'] = 'Valitse';
$lang['approve'] = 'Aseta tilaksi &quot;Julkaistu&quot;';
$lang['revert'] = 'Aseta tilaksi &quot;Luonnos&quot;';
$lang['hide_summary_field'] = 'Piilota &quot;yhteenveto&quot;-kentt&auml; lis&auml;ys- ja muokkaussivuilta';
$lang['textbox'] = 'Tekstikentt&auml;';
$lang['checkbox'] = 'Valintalaatikko';
$lang['textarea'] = 'Tekstialue';
$lang['file'] = 'Tiedosto';
$lang['auto_create_thumbnails'] = 'Luo pienoiskuvat automaattisesti seuraaville p&auml;&auml;tteille';
$lang['allowed_upload_types'] = 'Salli vain n&auml;m&auml; p&auml;&auml;tteet';
$lang['fielddefupdated'] = 'Kent&auml;n m&auml;&auml;rityksi&auml; p&auml;ivitetty';
$lang['editfielddef'] = 'Muokkaa kent&auml;n m&auml;&auml;rityst&auml;';
$lang['up'] = 'Yl&ouml;s';
$lang['down'] = 'Alas';
$lang['fielddefdeleted'] = 'Kentt&auml; poistettu';
$lang['nameexists'] = 'Kentt&auml; t&auml;ll&auml; nimell&auml; on jo olemassa';
$lang['notanumber'] = 'Maksimipituus ei ole numeerinen';
$lang['fielddef'] = 'Kent&auml;n m&auml;&auml;rittely';
$lang['fielddefadded'] = 'Kentt&auml; lis&auml;tty onnistuneesti';
$lang['public'] = 'Julkinen';
$lang['type'] = 'Tyyppi';
$lang['info_maxlength'] = 'Maksimipituus on k&auml;yt&ouml;ss&auml; vain tekstikentill&auml;';
$lang['maxlength'] = 'Maksimipituus';
$lang['addfielddef'] = 'Lis&auml;&auml; kentt&auml;';
$lang['customfields'] = 'Kent&auml;t';
$lang['deprecated'] = 'Ei tuettu';
$lang['subject_newnews'] = 'Uusi uutisartikkeli on julkaistu';
$lang['email_subject'] = 'L&auml;htev&auml;n postin aihe';
$lang['email_template'] = 'L&auml;htev&auml;n postin muoto';
$lang['formsubmit_emailaddress'] = 'S&auml;hk&ouml;postiosoite, johon l&auml;hetet&auml;&auml;n ilmoitus uusista artikkeleista';
$lang['extra'] = 'Lis&auml;';
$lang['uploadscategory'] = 'Latausten kategoria';
$lang['title_available_templates'] = 'K&auml;ytett&auml;viss&auml; olevat pohjat';
$lang['resettodefault'] = 'Palauta oletukset';
$lang['title_form_template'] = 'Lomakepohjan muokkaus';
$lang['title_detail_template'] = 'Yksityiskohtaisen pohjan muokkaus';
$lang['title_summary_template'] = 'Koostepohjan muokkaus';
$lang['prompt_templatename'] = 'Pohjan nimi';
$lang['prompt_template'] = 'Pohjan koodi';
$lang['title_form_sysdefault'] = 'Oletus lomakepohja';
$lang['title_summary_sysdefault'] = 'Oletus koostepohja';
$lang['title_detail_sysdefault'] = 'Oletus yksityiskohtainen pohja';
$lang['info_sysdefault2'] = '<strong>Huomioi:</strong> T&auml;m&auml; v&auml;lilehti sis&auml;lt&auml;&auml; tekstikentti&auml;, jotka sallivat uusien pohjien oletustietojen muokkauksen.<strong>N&auml;m&auml; eiv&auml;t vaikuta olemassa oleviin pohjiin!</strong>.';
$lang['info_sysdefault'] = '<em>(Pohja jota k&auml;ytet&auml;&auml;n oletuksena)</em>';
$lang['template'] = 'Pohja';
$lang['prompt_name'] = 'Nimi';
$lang['prompt_default'] = 'Oletus';
$lang['prompt_newtemplate'] = 'Luo uusi pohja';
$lang['help_pagelimit'] = 'Sivulla n&auml;kyvien uutisten enimm&auml;ism&auml;&auml;r&auml;. Jos t&auml;t&auml; parametri&auml; ei anneta, kaikki uutiset n&auml;ytet&auml;&auml;n. Jos t&auml;m&auml; parametri annetaan ja uutisia on enemm&auml;n kuin parametrin arvo, tulosten selaamiseen annetaan linkit.';
$lang['prompt_page'] = 'Sivu';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = '/';
$lang['prompt_pagelimit'] = 'Sivurajoitus';
$lang['prompt_sorting'] = 'J&auml;rjest&auml;';
$lang['title_filter'] = 'Suodatus';
$lang['published'] = 'Julkaistu';
$lang['draft'] = 'Luonnos';
$lang['expired'] = 'Vanhentunut';
$lang['author'] = 'Kirjoittaja';
$lang['sysdefaults'] = 'Palauta oletukset';
$lang['restoretodefaultsmsg'] = 'Haluatko varmasti palauttaa pohjan oletuspohjaksi?';
$lang['addarticle'] = 'Lis&auml;&auml; artikkeli';
$lang['articleadded'] = 'Artikkeli lis&auml;tty onnistuneesti.';
$lang['articleupdated'] = 'Artikkelin p&auml;ivitys onnistui.';
$lang['articledeleted'] = 'Artikkelin poistaminen onnistui.';
$lang['addcategory'] = 'Lis&auml;&auml; kategoria';
$lang['categoryadded'] = 'Kategoria lis&auml;tty onnistuneesti.';
$lang['categoryupdated'] = 'Kategoria p&auml;ivitetty onnistuneesti.';
$lang['categorydeleted'] = 'Kategorian poistaminen onnistui.';
$lang['addnewsitem'] = 'Lis&auml;&auml; uutisartikkeli';
$lang['allcategories'] = 'Kaikki kategoriat';
$lang['allentries'] = 'Kaikki artikkelit';
$lang['areyousure'] = 'Haluatko varmasti poistaa?';
$lang['articles'] = 'Artikkelit';
$lang['cancel'] = 'Peru';
$lang['category'] = 'Kategoria';
$lang['categories'] = 'Kategoriat';
$lang['default_category'] = 'Oletuskategoria';
$lang['content'] = 'Sis&auml;lt&ouml;';
$lang['dateformat'] = '%s ei ole muotoa yyyy-mm-dd hh:mm:ss!';
$lang['delete'] = 'Poista';
$lang['description'] = 'Lis&auml;&auml;, muokkaa ja poista uutisartikkeleita';
$lang['formtemplate'] = 'Lomakepohjat';
$lang['detailtemplate'] = 'Yksityiskohtainen pohja';
$lang['default_templates'] = 'Oletuspohjat';
$lang['detailtemplateupdated'] = 'P&auml;ivitetty yksityiskohtainen pohja tallennettiin tietokantaan.';
$lang['displaytemplate'] = 'N&auml;yt&auml; pohja';
$lang['edit'] = 'Muokkaa';
$lang['enddate'] = 'Lopetusp&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['endrequiresstart'] = 'Lopetusp&auml;iv&auml;m&auml;&auml;r&auml;n m&auml;&auml;rittely vaatii my&ouml;s aloitusp&auml;iv&auml;m&auml;&auml;r&auml;n';
$lang['entries'] = '%s artikkelia';
$lang['status'] = 'Tila';
$lang['expiry'] = 'Vanhentuminen';
$lang['filter'] = 'Suodatus';
$lang['more'] = 'Lis&auml;&auml;';
$lang['category_label'] = 'Kategoria: ';
$lang['author_label'] = 'Kirjoittaja: ';
$lang['moretext'] = 'Lue lis&auml;&auml;';
$lang['name'] = 'Nimi';
$lang['news'] = 'Uutiset';
$lang['news_return'] = 'Palaa';
$lang['newcategory'] = 'Uusi kategoria';
$lang['needpermission'] = 'Tarvitset &#039;%s&#039;-oikeuden suorittaaksesi t&auml;m&auml;n toiminnon.';
$lang['nocategorygiven'] = 'Kategoriaa ei annettu';
$lang['startdatetoolate'] = 'Aloitusp&auml;iv&auml;m&auml;&auml;r&auml; ei voi olla lopetusp&auml;iv&auml;m&auml;&auml;r&auml;n j&auml;lkeen!';
$lang['nocontentgiven'] = 'Ei sis&auml;lt&ouml;&auml; m&auml;&auml;ritelty';
$lang['noitemsfound'] = 'Kategorialle %s ei l&ouml;ydy artikkeleita';
$lang['nopostdategiven'] = 'P&auml;iv&auml;m&auml;&auml;r&auml;&auml; ei ole m&auml;&auml;ritelty';
$lang['note'] = '<em>Huomaa:</em> p&auml;iv&auml;m&auml;&auml;rien tulee olla muotoa \&#039;yyyy-mm-dd hh:mm:ss\&#039;.';
$lang['notitlegiven'] = 'Otsikkoa ei ole m&auml;&auml;ritelty';
$lang['nonamegiven'] = 'Nime&auml; ei ole m&auml;&auml;ritelty';
$lang['numbertodisplay'] = 'Kuinka monta n&auml;ytet&auml;&auml;n (tyhj&auml; = n&auml;ytet&auml;&auml;n kaikki)';
$lang['print'] = 'Tulosta';
$lang['postdate'] = 'P&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['postinstall'] = 'Aseta &quot;Muokkaa uutisia&quot; -oikeudet k&auml;ytt&auml;jille, jotka hallitsevat uutisia';
$lang['selectcategory'] = 'Valitse kategoria';
$lang['showchildcategories'] = 'N&auml;yt&auml; alakategoriat';
$lang['sortascending'] = 'Lajittele nousevasti';
$lang['startdate'] = 'Aloitusp&auml;iv&auml;m&auml;&auml;r&auml;';
$lang['startoffset'] = 'N&auml;yt&auml; alkaen n:nnest&auml; artikkelista';
$lang['startrequiresend'] = 'Aloitusp&auml;iv&auml;m&auml;&auml;r&auml;n m&auml;&auml;rittely tarvitsee my&ouml;s lopetusp&auml;iv&auml;m&auml;&auml;r&auml;n';
$lang['submit'] = 'L&auml;het&auml;';
$lang['summary'] = 'Kooste';
$lang['summarytemplate'] = 'Koostepohja';
$lang['summarytemplateupdated'] = 'Uutisten koostepohja onnistuneesti p&auml;ivitetty.';
$lang['title'] = 'Otsikko';
$lang['options'] = 'Valinnat';
$lang['optionsupdated'] = 'Valinnat onnistuneesti p&auml;ivitetty.';
$lang['useexpiration'] = 'K&auml;yt&auml; vanhentumisp&auml;iv&auml;m&auml;&auml;r&auml;&auml;';
$lang['eventdesc-NewsArticleAdded'] = 'L&auml;hetet&auml;&auml;n, kun artikkeli on lis&auml;tty.';
$lang['eventhelp-NewsArticleAdded'] = '<p>L&auml;hetet&auml;&auml;n kun artikkeli on lis&auml;tty.</p>
<h4>Parametrit</h4>
<ul>
<li>\&quot;news_id\&quot; - Uuden artikkelin tunniste</li>
<li>\&quot;category_id\&quot; - Artikkelin kategorian tunniste</li>
<li>\&quot;title\&quot; - Artikkelin otsikko</li>
<li>\&quot;content\&quot; - Artikkelin sis&auml;lt&ouml;</li>
<li>\&quot;summary\&quot; - Artikkelin yhteenveto</li>
<li>\&quot;status\&quot; - Artikkelin tila (\&quot;luonnos\&quot; tai \&quot;julkaistu\&quot;)</li>
<li>\&quot;start_time\&quot; - P&auml;iv&auml;m&auml;&auml;r&auml;, jolloin uutisen tulisi olla n&auml;kyviss&auml;</li>
<li>\&quot;end_time\&quot; - P&auml;iv&auml;m&auml;&auml;r&auml;, jolloin uutisen pit&auml;isi poistua n&auml;kyvist&auml;</li>
<li>\&quot;useexp\&quot; - Pit&auml;isik&ouml; vanhentumisp&auml;iv&auml;m&auml;&auml;r&auml; j&auml;tt&auml;&auml; huomiotta vai ei</li>
</ul>';
$lang['eventdesc-NewsArticleEdited'] = 'L&auml;hetet&auml;&auml;n, kun artikkelia on muokattu.';
$lang['eventhelp-NewsArticleEdited'] = '<p>L&auml;hetet&auml;&auml;n, kun artikkelia on muokattu.</p>
<h4>Parametrit</h4>
<ul>
<li>\&quot;news_id\&quot; - Aartikkelin tunniste</li>
<li>\&quot;category_id\&quot; - Artikkelin kategorian tunniste</li>
<li>\&quot;title\&quot; - Artikkelin otsikko</li>
<li>\&quot;content\&quot; - Artikkelin sis&auml;lt&ouml;</li>
<li>\&quot;summary\&quot; - Artikkelin yhteenveto</li>
<li>\&quot;status\&quot; - Artikkelin tila (\&quot;luonnos\&quot; tai \&quot;julkaistu\&quot;)</li>
<li>\&quot;start_time\&quot; - P&auml;iv&auml;m&auml;&auml;r&auml;, jolloin uutisen tulisi olla n&auml;kyviss&auml;</li>
<li>\&quot;end_time\&quot; - P&auml;iv&auml;m&auml;&auml;r&auml;, jolloin uutisen pit&auml;isi poistua n&auml;kyvist&auml;</li>
<li>\&quot;useexp\&quot; - Pit&auml;isik&ouml; vanhentumisp&auml;iv&auml;m&auml;&auml;r&auml; j&auml;tt&auml;&auml; huomiotta vai ei</li>
</ul>';
$lang['eventdesc-NewsArticleDeleted'] = 'L&auml;hetet&auml;&auml;n, kun artikkeli on poistettu.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>L&auml;hetet&auml;&auml;n, kun artikkeli on poistettu.</p>
<h4>Parametrit</h4>
<ul>
<li>\&quot;news_id\&quot; - Artikkelin tunniste</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'L&auml;hetet&auml;&auml;n, kun kategoria on lis&auml;tty.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>L&auml;hetet&auml;&auml;n, kun kategoria on lis&auml;tty.</p>
<h4>Parametrit</h4>
<ul>
<li>\&quot;category_id\&quot; - Uutiskategorian tunniste</li>
<li>\&quot;name\&quot; - Uutiskategorian nimi</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'L&auml;hetet&auml;&auml;n kun kategoriaa on muokattu.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>L&auml;hetet&auml;&auml;n, kun kategoriaa on muokattu.</p>
<h4>Parametrit</h4>
<ul>
<li>\&quot;category_id\&quot; - Uutiskategorian tunniste</li>
<li>\&quot;name\&quot; - Uutiskategorian nimi</li>
<li>\&quot;origname\&quot; - Uutiskategorian alkuper&auml;inen nimi</li>
</ul>';
$lang['eventdesc-NewsCategoryDeleted'] = 'L&auml;hetet&auml;&auml;n kun kategoria on poistettu.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>L&auml;hetet&auml;&auml;n, kun kategoria on poistettu.</p>
<h4>Parametrit</h4>
<ul>
<li>\&quot;category_id\&quot; - Poistetun kategorian tunniste</li>
<li>\&quot;name\&quot; - Poistetun kategorian nimi</li>
</ul>';
$lang['help_articleid'] = 'T&auml;m&auml; parametri koskee ainoastaan yksityiskohtaista n&auml;kym&auml;&auml;. Se m&auml;&auml;rittelee, mitk&auml; artikkelit n&auml;ytet&auml;&auml;n yksityiskohtaisessa tilassa. Jos erityisarvoa -1 k&auml;ytet&auml;&auml;n, j&auml;rjestelm&auml; n&auml;ytt&auml;&auml; uusimman, julkaistun ja vanhentumattoman artikkelin.';
$lang['helpnumber'] = 'Maksimim&auml;&auml;r&auml; n&auml;ytett&auml;vi&auml; artikkeleita (per sivu) -- tyhj&auml;ksi j&auml;tt&auml;minen n&auml;ytt&auml;&auml; kaikki artikkelit. T&auml;m&auml; on synonyymi pagelimit parametrille.';
$lang['helpstart'] = 'Aloita n:nnest&auml; artikkelista (tyhj&auml; aloittaa ensimm&auml;isest&auml;).';
$lang['helpcategory'] = 'N&auml;yt&auml; vain t&auml;m&auml;n kategorian artikkelit. <b>* kategorian nimen per&auml;ss&auml; n&auml;ytt&auml;&auml; my&ouml;s alikategoriat.</b> Voit m&auml;&auml;ritell&auml; useita kategorioita erottamalla ne toisistaan pilkulla. Tyhj&auml; n&auml;ytt&auml;&auml; kaikki kategoriat. T&auml;m&auml; parametri toimii my&ouml;s julkisten sivujen l&auml;hetystoiminnolle, mutta silloin ainoastaan yksi kategoria on mahdollinen.';
$lang['helpmoretext'] = 'Linkin teksti koko uutiseen, jos uutisen pituus on yli yhteenvedon pituuden. Oletus on &quot;Lis&auml;&auml;...&quot;';
$lang['helpsummarytemplate'] = 'K&auml;yt&auml; erillist&auml; tietokantapohjaa artikkelien yhteenvedon n&auml;ytt&auml;miseksi. T&auml;m&auml; pohja t&auml;ytyy olla olemassa ja n&auml;kyviss&auml; yhteenvetopohjan v&auml;lilehdess&auml; uutisten hallinnassa, mutta sen ei tarvitse olla oletuksena. Jos t&auml;m&auml; parametri ei ole m&auml;&auml;ritelty, silloin nykyinen pohja merkit&auml;&auml;n oletuksena k&auml;ytett&auml;v&auml;ksi.';
$lang['helpformtemplate'] = 'K&auml;yt&auml; tietokantapohjaa artikkelien l&auml;hetyslomakkeen n&auml;ytt&auml;miseksi.  T&auml;m&auml; pohja t&auml;ytyy olla olemassa ja n&auml;kyviss&auml; yhteenvetopohjan v&auml;lilehdess&auml; uutisten hallinnassa, mutta sen ei tarvitse olla oletuksena. Jos t&auml;m&auml; parametri ei ole m&auml;&auml;ritelty, silloin nykyinen pohja merkit&auml;&auml;n oletuksena k&auml;ytett&auml;v&auml;ksi.';
$lang['helpbrowsecattemplate'] = 'K&auml;yt&auml; tietokantapohjaa kategorioiden selaamisen n&auml;ytt&auml;miseksi. T&auml;m&auml; pohja t&auml;ytyy olla olemassa ja n&auml;kyviss&auml; yhteenvetopohjan v&auml;lilehdess&auml; uutisten hallinnassa, mutta sen ei tarvitse olla oletuksena. Jos t&auml;m&auml; parametri ei ole m&auml;&auml;ritelty, silloin nykyinen pohja merkit&auml;&auml;n oletuksena k&auml;ytett&auml;v&auml;ksi.';
$lang['helpdetailtemplate'] = 'K&auml;yt&auml; erillist&auml; tietokantapohjaa artikkelin yksityiskohtien n&auml;ytt&auml;miseksi. T&auml;m&auml; pohja t&auml;ytyy olla olemassa ja n&auml;kyviss&auml; yhteenvetopohjan v&auml;lilehdess&auml; uutisten hallinnassa, mutta sen ei tarvitse olla oletuksena. Jos t&auml;m&auml; parametri ei ole m&auml;&auml;ritelty, silloin nykyinen pohja merkit&auml;&auml;n oletuksena k&auml;ytett&auml;v&auml;ksi.';
$lang['helpsortby'] = 'Mink&auml; mukaan j&auml;rjestet&auml;&auml;n. Vaihtoehdot: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  Oletus on &quot;news_date&quot;. Jos &quot;random&quot; on m&auml;&auml;ritelty, sortasc parametria ei oteta huomioon.';
$lang['helpsortasc'] = 'J&auml;rjest&auml; artikkelit nousevasti p&auml;iv&auml;m&auml;&auml;r&auml;n mukaan.';
$lang['helpdetailpage'] = 'Sivu, jossa esitet&auml;&auml;n uutisen yksityiskohdat. T&auml;m&auml; voi olla sivun alias tai tunniste. Mahdollistaa uutisen yksityiskohtien n&auml;ytt&auml;misen eri mallipohjassa kuin uutisotsikot.';
$lang['helpshowarchive'] = 'N&auml;yt&auml; vain vanhentuneet uutisartikkelit.';
$lang['helpbrowsecat'] = 'N&auml;ytt&auml;&auml; selattavan kategorialistan.';
$lang['helpaction'] = 'Ylikirjoita oletustoiminto. Mahdolliset arvot:
<ul>
<li>&amp;quot;detail&amp;quot; - tietyn artikkelin n&auml;ytt&auml;miseksi yksityiskohtaisessa tilassa.</li>
<li>&amp;quot;default&amp;quot; - yhteenvetotilan n&auml;ytt&auml;miseksi</li>
<li>&amp;quot;fesubmit&amp;quot; - julkisten sivujen lomakkeen n&auml;ytt&auml;miseksi, jolla k&auml;ytt&auml;j&auml;t voivat l&auml;hett&auml;&auml; uutisia.</li>
<li>&amp;quot;browsecat&amp;quot; -selattavan kategorialistan n&auml;ytt&auml;miseksi.</li>
</ul>';
$lang['help'] = '<h3>T&auml;rkeit&auml; muistiinpanoja</h3>
<p>Versiosta 2.9 l&auml;htien Uutiset on poistanut formatpostdate j&auml;senen pohjista, ja my&ouml;s dateformat parametri on poistettu. Sinun tulisi k&auml;ytt&auml;&auml; cms_date_format muuttujaa (kuten n&auml;ytet&auml;&auml;n oletuspohjassa) p&auml;iv&auml;m&auml;&auml;rien muokkaamiseksi, ja tulisi k&auml;ytt&auml;&auml; entry->formatpostdaten sijasta entry->postdatea.</p>
<h3>Mit&auml; t&auml;m&auml; tekee?</h3>
<p>Uutiset on moduuli, jolla voidaan n&auml;ytt&auml;&auml; uutisia sivuillasi, samaan tyyliin kuin blogeissa, mutta monipuolisemmilla toiminnoilla! Kun moduuli on asennettu, hallintapaneeliin lis&auml;t&auml;&auml;n uutisten hallintavalikko, joka sallii sinun valita tai lis&auml;t&auml; uutiskategorioita. Kun uutiskategoria on luotu tai valittu, n&auml;ytet&auml;&auml;n lista uutisartikkeleista kategoriassa. T&auml;&auml;lt&auml; voit lis&auml;t&auml;, muokata tai poistaa uutisia t&auml;st&auml; kategoriasta.</p>
<h4>Useita n&auml;ytt&ouml;mahdollisuuksia</h4>
<p>Uutismoduulin tukemat parametrit ja pohjat merkitsev&auml;t sit&auml;, ett&auml; tavat n&auml;ytt&auml;&auml; uutisia ovat l&auml;hes rajattomat.</p>
<h4>Mukautetut kent&auml;t</h4>
<p>Uutismoduuli sallii useiden mukautettujen kenttien m&auml;&auml;ritt&auml;misen (mukaan lukien tiedostot ja kuvat), jotka sallivat sinun liitt&auml;&auml; pdf-tiedostoja tai kuvia uutisiin.p>
        <h4>Kategoriat</h4>
	<p>Uutiset tuo mukanaan hierarkisen kategoriaj&auml;rjestelm&auml;n, jonka avulla voit j&auml;rjest&auml;&auml; artikkelesi. Uutisartikkeli voi sijaita ainoastaan yhdess&auml; paikassa hierarkiassa.</p>
	<h4>Vanhentuminen ja tila</h4>
	<p>Jokaisella uutisartikkelilla voi olla vapaaehtoinen vanhentumaika, jonka j&auml;lkeen sit&auml; ei en&auml;&auml; n&auml;ytet&auml; sivustoltasi. Artikkelit voidaan my&ouml;s merkit&auml; <em>luonnoksiksi</em>, jolloin ne poistuvat pysyv&auml;sti sivustoltasi.</p>
	<h3>Turvallisuus</h3>
	<p>K&auml;ytt&auml;j&auml;n t&auml;ytyy kuulua ryhm&auml;&auml;n, jolla on oikeus muokata uutisia, jotta h&auml;n voi lis&auml;t&auml; tai muokata uutisartikkeleita.</p>
        <p>Samoin k&auml;ytt&auml;j&auml; voi poistaa uutisia, jos h&auml;n kuuluu ryhm&auml;&auml;n, jolla on &#039;Poistaa uutisia&#039; -oikeus.</p>
	<p>Jotta k&auml;ytt&auml;j&auml; voi muokata sivupohjia, t&auml;ytyy h&auml;nen kuulua ryhm&auml;&auml;n, jolla on &#039;Muokata sivupohjia&#039; -oikeus.</p>
	<p>Jotta h&auml;n voisi muokata yleisi&auml; uutisasetuksia, h&auml;nen t&auml;ytyy kuulua ryhm&auml;&auml;n, jolla on &#039;Sivuston asetusten muokkaus&#039; -oikeus.</p>
	<p>Lis&auml;ksi, jotta k&auml;ytt&auml;j&auml; voi hyv&auml;ksy&auml; julkisilta sivuilta l&auml;hetettyj&auml; uutisia, k&auml;ytt&auml;j&auml;n t&auml;ytyy kuulua ryhm&auml;&auml;n, jolla on &#039;Hyv&auml;ksy&auml; uutisia&#039; -oikeus.</p>
	<h3>Kuinka k&auml;yt&auml;n sit&auml;?</h3>
	<p>Helpointa on k&auml;ytt&auml;&auml; {news} k&auml;&auml;retagia (k&auml;&auml;rii moduulin tagiin). T&auml;m&auml; lis&auml;&auml; moduulin sivupohjaasi tai sivulle uutisten n&auml;ytt&auml;miseksi. Koodi voi n&auml;ytt&auml;&auml; t&auml;lt&auml;: <code>{news number=&#039;5&#039;}</code></p>
<h3>Sivupohjat</h3>
<p>Versiosta 2.3 alkaen uutiset ovat tukeneet useampia tietokannassa olevia pohjia eik&auml; se en&auml;&auml; tue tiedostossa olevia pohjia. K&auml;ytt&auml;j&auml;t, jotka ovat k&auml;ytt&auml;neet vanhoja pohjia tulisi seurata seuraavia ohjeita (jokaiselle tiedostopohjalle):</p>
<ul>
<li>Kopioi tiedostossa oleva pohja leikep&ouml;yd&auml;lle</li>
<li>Luo uusi pohja tietokantaan <em>(joko kooste tai yksityiskohtainen on vaadittu)</em> Anna uudelle pohjalle sama nimi (mukaan lukien .tpl p&auml;&auml;te) kuin vanhalla pohjalla, ja liit&auml; sis&auml;ll&ouml;t siihen.</li>
<li>Paina L&auml;het&auml;</li>
</ul>
<p>N&auml;iden ohjeiden seuraamisen pit&auml;isi ratkaista ongelmat uutispohjien l&ouml;ytymisen ja muiden smarty-virheiden kanssa, kun p&auml;ivitet&auml;t uudempaan versioon CMS-j&auml;rjestelm&auml;&auml;.</p>';
$lang['qca'] = 'P0-143593381-1287469720325';
$lang['utmz'] = '156861353.1289907526.70.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,48780.0.html';
$lang['utma'] = '156861353.386609350.1282051258.1289907526.1289915269.71';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1289915269';
?>